<?php

require_once "config.inc";
require_once "sessions.inc";
require_once "constants.inc";
require_once "db.inc";
require_once "error.inc";
require_once "privpref.inc";
require_once "MARC.inc";

$MARC_author_display = array('100' => '%a - %d');

function search($criteria, $query, $position, $how_many = 10, $alternate_host = "", $additional_fetch_syntax = "", $extra_attribs = "")
{
		global $config, $YAZ_attributes, $langText;

        if (!empty ($_REQUEST['order_by']) && !empty ($_REQUEST['order_dir']))
		$order_syntax = $_REQUEST['order_by'] . " " . $_REQUEST['order_dir'];
        else
        	$order_syntax = "1=1004 ai"; //Default: Title [a]scending & case [i]nsensitive

		if($alternate_host == "")
			$full_host = $config['zebra_host'] . ":" . $config['zebra_port'] . "/" . $config['zebra_db'];
		else
			$full_host = $alternate_host;

		$YAZ_syntax = "USMARC"; //Default syntax for retrieval of MARC-data is xml. Temporarily USMARC is used.

		if($alternate_host != "" && array_key_exists($alternate_host, $YAZ_attributes) && array_key_exists($criteria, $YAZ_attributes[$alternate_host]))
			$criteria = $YAZ_attributes[$alternate_host][$criteria];
		elseif($criteria != "")
			$criteria = $YAZ_attributes[$criteria];

		if(stristr($query, "@") && $extra_attribs == "") {
			$YAZ_query = $criteria ." ". $query;
		}
		elseif(stristr($query, "@") && $extra_attribs != "" && $criteria == "") {
			$YAZ_query = $extra_attribs . " " . $query;
		}
		elseif($extra_attribs == "") {
			$YAZ_query = $criteria . ' "' . $query . '"';
		}
		else {
			$YAZ_query = $criteria .' ' . $extra_attribs . ' "' . $query . '"';
		}
		
		//print "FINAL QUERY: ".$YAZ_query;

		$id = yaz_connect($full_host, array("persistent" => false));
		//yaz_sort($id, $order_syntax);

		if (!yaz_search($id,"rpn",$YAZ_query))
		{
            error("bad search");
            exit;
        }

		if (isset($_REQUEST['element'])) {
			yaz_element($id,$_REQUEST['element']); //Specify the element to use. F since due to quick-search.
		}
		else {
			yaz_element($id,'F');
		}

		yaz_syntax($id,$YAZ_syntax); //Specify the syntax; XML.
		yaz_range($id,$position,$how_many); //Specify at which record to start and how many records to fetch.

		yaz_wait( array ("timeout" => 30)); //Wait for responce with a timeout of 30s

		$YAZ_error = yaz_error($id); //Error description
        $YAZ_errno = yaz_errno($id); //Error number
        $YAZ_addinfo = yaz_addinfo($id); //Additional error information

		if ($YAZ_errno)
        {
			//error("yaz server error"); //Inform the error-function about the error
            if($YAZ_errno >= 10000)
				layout_page_info($langText['YAZ_'.$YAZ_errno], 'error');
			else{
				if($YAZ_addinfo == "")
					$add = "";
				else
					$add = ": ".$YAZ_addinfo;

				layout_page_info($YAZ_error.$add, 'error');
			}

			return array(array(), 0, array());
			//writeLog("Yaz request error: $YAZ_error (code $YAZ_errno) $YAZ_addinfo"); //Make log-entry, requires sessions.inc
        }
		else
		{
			$YAZ_records = array();
			$YAZ_additional = array();
			$counter = 0;
			$hits = yaz_hits($id);
			if($how_many == 'hits') {
				yaz_range($id,$position,$hits); //Specify at which record to start and how many records to fetch.
				$how_many = $hits;
			}
			for ($pos = $position; $pos <= $how_many+$position; $pos++)
			{
				$YAZ_rec = yaz_record($id,$pos,"xml"); //Fetch records in "string" format due to XML. "XML" temporarily.
				if(empty($YAZ_rec)) //If no more records, break the loop.
					continue;
				$YAZ_records[$counter] = $YAZ_rec;
				$counter++;
				//array_push($YAZ_records, $YAZ_rec);
			}
			if($additional_fetch_syntax != "") {
				$counter = 0;
				for ($pos = 1; $pos <= $how_many; $pos++)
				{
					$YAZ_rec = yaz_record($id,$pos,$additional_fetch_syntax); //Fetch records in format specified as argument.
					$YAZ_additional[$counter] = $YAZ_rec;
					$counter++;
					//array_push($YAZ_additional, $YAZ_rec);
					if(empty($YAZ_rec)) //If no more records, break the loop.
						continue;
				}
			}

			yaz_close($id);

			return array($YAZ_records, $hits, $YAZ_additional); //Return the array containing the XML-records and additional record if specified.
		}
}

function expiry_date($timestamp, $date_format = USER_DATE_FORMAT)
{
	global $config;
	$default_time = $timestamp + $config['borrow_time'] * 86400;
	$extra_time = 0;
	if(date("D", $default_time) == "Sat")
		$extra_time = 172800;
	if(date("D", $default_time) == "Sun")
		$extra_time = 86400;
	return array(date($date_format, ($default_time + $extra_time)), ($default_time + $extra_time));
}

function is_book($id)
{
	global $config;

	if(is_last_char($id, $config['book_id_suffix']) && is_numeric(chop_last($id)))
		return true;
	else
		return false;
}

function create_page_index($hits, $position, $hits_per_page, $base_url)
{
	if($hits >= $position)
	{
		$page_index = "";
		$pos = (($position - 1)/$hits_per_page);
		$before = (($position - 1)/$hits_per_page);
		$after = floor(($hits - $position)/$hits_per_page);
		if($before >= 5 && $after >= 5) {
			$before = 5;
			$after = 5;
		}
		elseif($before > 5 && $after < 5)
			$before = floor($hits/$hits_per_page) - $after;
		elseif($after > 5 && $before < 5) {
			if(floor(($hits - $position)/$hits_per_page) > 10)
				$after = 10 - $before;
			else
				$after = floor(($hits - $position)/$hits_per_page) - $before;
		}

		/*
		print "HITS: ".$hits;
		print "BEFORE: ".$before;
		print "AFTER: ".$after;
		print "POS: ".$pos;
		*/

		$start = $pos - $before;
		$end = $pos + $after;

		/*
		print "START: ".$start;
		print "END: ".$end;
		*/

		$page_index .= "<span class='page-index'>";

		if(((($pos - 1)*$hits_per_page) + 1)  > 0)
			$page_index .= "<a href='".$base_url."&position=".((($pos - 1)*$hits_per_page) + 1)."'>&lt;&lt;</a>";

		for ($p = 0; $p < $before; $p++) {
				$page_index .= "&nbsp;&nbsp;<a href='".$base_url."&position=".(($start*$hits_per_page)+($p*$hits_per_page)+1)."'>".(($p+$start)+1)."</a>";
		}
		$page_index .= "&nbsp;&nbsp;<a href='".$base_url."&position=".(($pos*$hits_per_page)+1)."'><b>".($pos+1)."</b></a>";

		for ($p = 1; $p <= $after; $p++) {
			$page_index .= "&nbsp;&nbsp;<a href='".$base_url."&position=".(($pos*$hits_per_page)+(($p)*$hits_per_page)+1)."'>".(($p+$pos)+1)."</a>";
		}

		if(((($pos + 1)*$hits_per_page) + 1) <= $hits)
			$page_index .= "&nbsp;&nbsp;<a href='".$base_url."&position=".((($pos + 1)*$hits_per_page) + 1)."'>&gt;&gt;</a>";

		$page_index .= "</span>";

		if ($before == 0 && $after == 0)
			return "";
		else
			return $page_index;
	}
}

function guess_filtered_hits($hits, $hits_per_page, $total_looped, $accepted_looped)
{
	if($hits > $hits_per_page) {
 		$pages = floor($hits/$hits_per_page);
	} else {
		$pages = 1;
	}
	
	$failed = $total_looped - $accepted_looped;
	$total_failed = $failed * $pages;
	
	return ($hits - $total_failed);
}

?>
